# -*- coding: utf-8 -*-
# Generated by Django 1.10.2 on 2016-11-24 20:24
from __future__ import unicode_literals

import datetime
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='BadgeAward',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('slug', models.CharField(max_length=255, verbose_name='slug')),
                ('level', models.IntegerField(verbose_name='level')),
                ('points', models.PositiveIntegerField(default=0, verbose_name='points')),
                ('awarded_on', models.DateTimeField(default=datetime.datetime.now, verbose_name='awarded on')),
                ('created_on', models.DateTimeField(auto_now_add=True, verbose_name='created on')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='badges_earned', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'badge award',
                'verbose_name_plural': 'badge awards',
            },
        ),
    ]
